/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 */

#ifndef NACTV_UTILS_H
#define NACTV_UTILS_H

#include <glib.h>
#include <stdio.h>
#include <string.h>

void match_string_length (char **dest, int len);
char *get_bytes_string_base (unsigned long long nbytes, unsigned long long base,
							 const char *format, const char *formatd);
char* get_bytes_string (unsigned long long nbytes);

gboolean drop_effective_user_to_sudo ();
void restore_effective_user ();
const char* get_effective_home_dir ();

void set_clipboard_text (const char *text);

void EnsureStringLen (char **str, int *maxSize, int len);
/*Allocates a very large pesimistic buffer inside. Do not use if 'from' is very short compared to 'to' on a large 'str'.*/
char *string_replace (const char* str, const char * from, const char* to);

const char *get_file_extension (const char *fileName);

/**********************************IntArray*/

typedef struct
{
	int *data;
	int len;
	int allocatedLen;
}IntArray;

static inline void IntArrayInit (IntArray *arr, int startAllocLen)
{
	g_assert(startAllocLen > 1);
	arr->allocatedLen = startAllocLen;
	arr->data = (int*)g_malloc0(arr->allocatedLen * sizeof(int));
	arr->len = 0;
}

static inline void IntArrayFreeInternal (IntArray *arr)
{
	if (arr->data != NULL)
	{
		g_free(arr->data);
		arr->data = NULL;
	}
	arr->len = arr->allocatedLen = 0;
}

static inline void IntArrayEnsureAlloc (IntArray *arr, int nrAddItems)
{	
	if (arr->len + nrAddItems > arr->allocatedLen)
	{
		int newAllocLen = (arr->len + nrAddItems) * 2;		
		arr->data = (int*)g_realloc(arr->data, newAllocLen * sizeof(int));
		memset(arr->data + arr->allocatedLen, 0, newAllocLen - arr->allocatedLen);
		arr->allocatedLen = newAllocLen;
	}	
}

static inline void IntArrayAdd (IntArray *arr, int x)
{
	IntArrayEnsureAlloc(arr, 1);
	arr->data[arr->len] = x;
	arr->len++;
}

static inline void IntArrayRemoveLast (IntArray *arr)
{
	g_assert(arr->len > 0);
	arr->len--;
}

static inline int IntArrayE (IntArray *arr, int i)
{
	g_assert(i>=0 && i<arr->len);
	return arr->data[i];
}

/**********************************IntArray*/




#endif /*NACTV_UTILS_H*/
